[前][次][番号順一覧][スレッド一覧]

ruby-changes:6602

From: shyouhei <ko1@a...>
Date: Thu, 17 Jul 2008 21:43:05 +0900 (JST)
Subject: [ruby-changes:6602] Ruby:r18118 (ruby_1_8_7): * lib/net/smtp.rb (Net::SMTP::start): revert to avoid RFC2821

shyouhei	2008-07-17 21:42:52 +0900 (Thu, 17 Jul 2008)

  New Revision: 18118

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=18118

  Log:
    * lib/net/smtp.rb (Net::SMTP::start): revert to avoid RFC2821
      violation. [ruby-dev:35487]

  Modified files:
    branches/ruby_1_8_7/ChangeLog
    branches/ruby_1_8_7/lib/net/smtp.rb
    branches/ruby_1_8_7/version.h

Index: ruby_1_8_7/ChangeLog
===================================================================
--- ruby_1_8_7/ChangeLog	(revision 18117)
+++ ruby_1_8_7/ChangeLog	(revision 18118)
@@ -1,3 +1,8 @@
+Thu Jul 17 21:42:07 2008  URABE Shyouhei  <shyouhei@r...>
+
+	* lib/net/smtp.rb (Net::SMTP::start): revert to avoid RFC2821
+	  violation. [ruby-dev:35487]
+
 Thu Jul 17 21:32:49 2008  Tanaka Akira  <akr@f...>
 
 	* string.c (rb_str_format_m): make tmp volatile to avoid possible GC
Index: ruby_1_8_7/version.h
===================================================================
--- ruby_1_8_7/version.h	(revision 18117)
+++ ruby_1_8_7/version.h	(revision 18118)
@@ -2,7 +2,7 @@
 #define RUBY_RELEASE_DATE "2008-07-17"
 #define RUBY_VERSION_CODE 187
 #define RUBY_RELEASE_CODE 20080717
-#define RUBY_PATCHLEVEL 62
+#define RUBY_PATCHLEVEL 63
 
 #define RUBY_VERSION_MAJOR 1
 #define RUBY_VERSION_MINOR 8
Index: ruby_1_8_7/lib/net/smtp.rb
===================================================================
--- ruby_1_8_7/lib/net/smtp.rb	(revision 18117)
+++ ruby_1_8_7/lib/net/smtp.rb	(revision 18118)
@@ -437,7 +437,7 @@
     # +port+ is the port to connect to; it defaults to port 25.
     #
     # +helo+ is the _HELO_ _domain_ provided by the client to the
     # server (see overview comments); it defaults to 'localhost'. 
     #
     # The remaining arguments are used for SMTP authentication, if required
     # or desired.  +user+ is the account name; +secret+ is your password
@@ -457,7 +457,7 @@
     # * IOError
     # * TimeoutError
     #
-    def SMTP.start(address, port = nil, helo = 'localhost',
+    def SMTP.start(address, port = nil, helo = 'localhost.localdomain',
                    user = nil, secret = nil, authtype = nil,
                    &block)   # :yield: smtp
       new(address, port).start(helo, user, secret, authtype, &block)
@@ -518,7 +518,7 @@
     # * IOError
     # * TimeoutError
     #
-    def start(helo = 'localhost',
+    def start(helo = 'localhost.localdomain',
               user = nil, secret = nil, authtype = nil)   # :yield: smtp
       if block_given?
         begin
@@ -437,7 +437,7 @@
     #
     # +helo+ is the _HELO_ _domain_ provided by the client to the
-    # server (see overview comments); it defaults to 'localhost'. 
+    # server (see overview comments); it defaults to 'localhost.localdomain'. 
     #
     # The remaining arguments are used for SMTP authentication, if required

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]